using FitConnect.Services.Models.v1.Submission;

namespace FitConnect.Services.Interfaces;

public interface ISubmissionService : IRestCallService {
    /// <summary>
    ///     <para>@PostMapping("/submissions")</para>
    /// </summary>
    /// <param name="submissionDto">RequestBody</param>
    /// <returns></returns>
    Task<SubmissionCreatedDto> CreateSubmissionAsync(CreateSubmissionDto submissionDto);

    /// <summary>
    ///     <para>
    ///         @PutMapping(value = "/submissions/{submissionId}/attachments/{attachmentId}", consumes =
    ///         "application/jose")
    ///     </para>
    /// </summary>
    /// <param name="submissionId">PathVariable</param>
    /// <param name="attachmentId">PathVariable</param>
    /// <param name="encryptedAttachmentContent">RequestBody</param>
    /// <returns></returns>
    Task<bool> AddSubmissionAttachment(Guid submissionId, Guid attachmentId,
        string encryptedAttachmentContent);

    /// <summary>
    ///     <para>@PutMapping(value = "/submissions/{submissionId}", consumes = "application/json") </para>
    /// </summary>
    /// <param name="submissionId">PathVariable</param>
    /// <param name="submitSubmission">RequestBody</param>
    /// <returns></returns>
    Task<SubmissionReducedDto?> SubmitSubmission(Guid submissionId,
        SubmitSubmissionDto submitSubmission);

    /// <summary>
    ///     <para>@GetMapping("/submissions")</para>
    /// </summary>
    /// <param name="destinationId">RequestParam</param>
    /// <param name="offset">How many entries of the result should be skipped</param>
    /// <param name="limit">How many result sets should be loaded</param>
    /// <returns></returns>
    Task<SubmissionsForPickupDto> ListSubmissionsAsync(Guid? destinationId, int offset,
        int limit);

    /// <summary>
    ///     <para>@GetMapping("/submissions/{submissionId}")</para>
    /// </summary>
    /// <param name="submissionId">PathVariable</param>
    /// <returns></returns>
    Task<SubmissionDto> GetSubmissionAsync(Guid submissionId);

    /// <summary>
    ///     <para>
    ///         @GetMapping(value = "/submissions/{submissionId}/attachments/{attachmentId}", produces =
    ///         "application/jose")
    ///     </para>
    /// </summary>
    /// <param name="submissionId">PathVariable</param>
    /// <param name="attachmentId">PathVariable</param>
    /// <returns></returns>
    Task<string> GetAttachmentAsync(Guid submissionId, Guid attachmentId);

    /// <summary>
    ///     Receiving the encryption key from the submission api
    /// </summary>
    /// <param name="keyId"></param>
    /// <returns></returns>
    string GetKey(string keyId);


    /// <summary>
    ///     Uploads an attachment to the submission api
    /// </summary>
    /// <param name="submissionId"></param>
    /// <param name="attachmentId"></param>
    /// <param name="content"></param>
    async Task UploadAttachment(Guid submissionId, Guid attachmentId, string content) {
        await AddSubmissionAttachment(submissionId, attachmentId, content);
    }

    /// <summary>
    ///     Retrieves the events of a submission
    /// </summary>
    /// <param name="caseId"></param>
    /// <param name="destinationId"></param>
    /// <param name="skipTest"></param>
    /// <returns></returns>
    Task<List<string>?> GetEventLogAsync(Guid caseId, Guid destinationId,
        bool skipTest = false);
}

public interface ICasesService {
    public Task<string> FinishSubmissionAsync(Guid caseId, string token);
}
